run_session

Function run_session 

pub fn run_session(socket_path: &str) -> Result<()>
Connect to a term-session-server and run the TUI viewer.

This function is synchronous. It creates a background tokio runtime for muxio IPC, then runs the synchronous crossterm event loop on the calling thread.